@@ -2,6 +2,7 @@
  *
  * GNOME Power Manager Brightness Applet
  * Copyright (C) 2006 Benjamin Canou <bookeldor@gmail.com>
+ * Copyright (C) 2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -31,49 +32,155 @@
 #include <gtk/gtkbox.h>
 #include <libgnomeui/gnome-help.h>
 #include <gdk/gdkkeysyms.h>
-#include <libgpm.h>
+#include <libdbus-watch.h>
+#include <glib-object.h>
+#include <dbus/dbus-glib.h>
+
+#include "../src/gpm-common.h"
+
+#define GPM_TYPE_BRIGHTNESS_APPLET		(gpm_brightness_applet_get_type ())
+#define GPM_BRIGHTNESS_APPLET(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), GPM_TYPE_BRIGHTNESS_APPLET, GpmBrightnessApplet))
+#define GPM_BRIGHTNESS_APPLET_CLASS(k)		(G_TYPE_CHECK_CLASS_CAST((k), GPM_TYPE_BRIGHTNESS_APPLET, GpmBrightnessAppletClass))
+#define GPM_IS_BRIGHTNESS_APPLET(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), GPM_TYPE_BRIGHTNESS_APPLET))
+#define GPM_IS_BRIGHTNESS_APPLET_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), GPM_TYPE_BRIGHTNESS_APPLET))
+#define GPM_BRIGHTNESS_APPLET_GET_CLASS(o)	(G_TYPE_INSTANCE_GET_CLASS ((o), GPM_TYPE_BRIGHTNESS_APPLET, GpmBrightnessAppletClass))
+
+typedef struct{
+	PanelApplet parent;
+	/* applet state */
+	gboolean call_worked; /* g-p-m refusing action */
+	gboolean popped; /* the popup is shown */
+	/* the popup and its widgets */
+	GtkWidget *popup, *slider, *btn_plus, *btn_minus;
+	/* the icon and a cache for size*/
+	GdkPixbuf *icon;
+	gint icon_width, icon_height;
+	/* connection to g-p-m */
+	DBusGProxy *proxy;
+	DBusGConnection *connection;
+	DbusWatch *watch;
+	guint level;
+	/* a cache for panel size */
+	gint size;
+} GpmBrightnessApplet;
+
+typedef struct{
+	PanelAppletClass	parent_class;
+} GpmBrightnessAppletClass;
+
+GType                gpm_brightness_applet_get_type  (void);
 
-#include "brightness-applet.h"
 
 static void      gpm_brightness_applet_class_init (GpmBrightnessAppletClass *klass);
 static void      gpm_brightness_applet_init       (GpmBrightnessApplet *applet);
 
 G_DEFINE_TYPE (GpmBrightnessApplet, gpm_brightness_applet, PANEL_TYPE_APPLET)
 
-static void      retrieve_icon                    (GpmBrightnessApplet *applet);
-static void      check_size                       (GpmBrightnessApplet *applet);
-static gboolean  draw_applet_cb                   (GpmBrightnessApplet *applet);
-static gboolean  destroy_popup_cb                 (GpmBrightnessApplet *applet);
-static void      update_tooltip                   (GpmBrightnessApplet *applet);
-static void      update_level                     (GpmBrightnessApplet *applet, gboolean hw_get, gboolean hw_set);
-static gboolean  plus_cb                          (GtkWidget *w, GpmBrightnessApplet *applet);
-static gboolean  minus_cb                         (GtkWidget *w, GpmBrightnessApplet *applet);
-static gboolean  key_press_cb                     (GpmBrightnessApplet *applet, GdkEventKey   *event);
-static gboolean  scroll_cb                        (GpmBrightnessApplet *applet, GdkEventScroll *event);
-static gboolean  slide_cb                         (GtkWidget *w, GpmBrightnessApplet *applet);
-static void      create_popup                     (GpmBrightnessApplet *applet);
-static gboolean  popup_cb                         (GpmBrightnessApplet *applet, GdkEventButton *event);
-static void      dialog_about_cb                  (BonoboUIComponent *uic, gpointer data, const gchar *verbname);
-static gboolean  bonobo_cb                        (PanelApplet *_applet, const gchar *iid, gpointer data);
-static void      destroy_cb                       (GtkObject *object);
+static void      gpm_applet_get_icon              (GpmBrightnessApplet *applet);
+static void      gpm_applet_check_size            (GpmBrightnessApplet *applet);
+static gboolean  gpm_applet_draw_cb               (GpmBrightnessApplet *applet);
+static void      gpm_applet_change_background_cb  (GpmBrightnessApplet *applet,
+						   PanelAppletBackgroundType arg1,
+						   GdkColor *arg2, GdkPixmap *arg3, gpointer data);
+static void      gpm_applet_theme_change_cb (GtkIconTheme *icon_theme, gpointer data);
+static void      gpm_applet_stop_scroll_events_cb (GtkWidget *widget, GdkEvent  *event);
+static gboolean  gpm_applet_destroy_popup_cb      (GpmBrightnessApplet *applet);
+static void      gpm_applet_update_tooltip        (GpmBrightnessApplet *applet);
+static void      gpm_applet_update_popup_level    (GpmBrightnessApplet *applet);
+static gboolean  gpm_applet_plus_cb               (GtkWidget *w, GpmBrightnessApplet *applet);
+static gboolean  gpm_applet_minus_cb              (GtkWidget *w, GpmBrightnessApplet *applet);
+static gboolean  gpm_applet_key_press_cb          (GpmBrightnessApplet *applet, GdkEventKey *event);
+static gboolean  gpm_applet_scroll_cb             (GpmBrightnessApplet *applet, GdkEventScroll *event);
+static gboolean  gpm_applet_slide_cb              (GtkWidget *w, GpmBrightnessApplet *applet);
+static void      gpm_applet_create_popup          (GpmBrightnessApplet *applet);
+static gboolean  gpm_applet_popup_cb              (GpmBrightnessApplet *applet, GdkEventButton *event);
+static void      gpm_applet_dialog_about_cb       (BonoboUIComponent *uic, gpointer data, const gchar *verbname);
+static gboolean  gpm_applet_bonobo_cb             (PanelApplet *_applet, const gchar *iid, gpointer data);
+static void      gpm_applet_destroy_cb            (GtkObject *object);
 
 #define GPM_BRIGHTNESS_APPLET_OAFID		"OAFIID:GNOME_BrightnessApplet"
 #define GPM_BRIGHTNESS_APPLET_FACTORY_OAFID	"OAFIID:GNOME_BrightnessApplet_Factory"
-#define GPM_BRIGHTNESS_APPLET_ICON		"gpm-brightness-lcd"
+#define GPM_BRIGHTNESS_APPLET_ICON		"gnome-brightness-applet"
 #define GPM_BRIGHTNESS_APPLET_ICON_DISABLED	"gpm-brightness-lcd-disabled"
+#define GPM_BRIGHTNESS_APPLET_ICON_INVALID	"gpm-brightness-lcd-invalid"
 #define GPM_BRIGHTNESS_APPLET_NAME		_("Power Manager Brightness Applet")
 #define GPM_BRIGHTNESS_APPLET_DESC		_("Adjusts laptop panel brightness.")
 #define PANEL_APPLET_VERTICAL(p)					\
 	 (((p) == PANEL_APPLET_ORIENT_LEFT) || ((p) == PANEL_APPLET_ORIENT_RIGHT))
 
 /**
- * retrieve_icon:
+ * gpm_applet_get_brightness:
+ * Return value: Success value, or zero for failure
+ **/
+static gboolean
+gpm_applet_get_brightness (GpmBrightnessApplet *applet)
+{
+	GError  *error = NULL;
+	gboolean ret;
+	guint policy_brightness;
+
+	if (applet->proxy == NULL) {
+		printf ("WARNING: not connected\n");
+		return FALSE;
+	}
+
+	ret = dbus_g_proxy_call (applet->proxy, "GetBrightness", &error,
+				 G_TYPE_INVALID,
+				 G_TYPE_UINT, &policy_brightness,
+				 G_TYPE_INVALID);
+	if (error) {
+		printf ("DEBUG: ERROR: %s\n", error->message);
+		g_error_free (error);
+	}
+	if (ret == TRUE) {
+		applet->level = policy_brightness;
+	} else {
+		/* abort as the DBUS method failed */
+		printf ("WARNING: GetBrightness failed!\n");
+	}
+
+	return ret;
+}
+
+/**
+ * gpm_applet_set_brightness:
+ * Return value: Success value, or zero for failure
+ **/
+static gboolean
+gpm_applet_set_brightness (GpmBrightnessApplet *applet)
+{
+	GError  *error = NULL;
+	gboolean ret;
+
+	if (applet->proxy == NULL) {
+		printf ("WARNING: not connected");
+		return FALSE;
+	}
+
+	ret = dbus_g_proxy_call (applet->proxy, "SetBrightness", &error,
+				 G_TYPE_UINT, applet->level,
+				 G_TYPE_INVALID,
+				 G_TYPE_INVALID);
+	if (error) {
+		printf ("DEBUG: ERROR: %s", error->message);
+		g_error_free (error);
+	}
+	if (ret == FALSE) {
+		/* abort as the DBUS method failed */
+		printf ("WARNING: SetBrightness failed!");
+	}
+
+	return ret;
+}
+
+/**
+ * gpm_applet_get_icon:
  * @applet: Brightness applet instance
  *
  * retrieve an icon from stock with a size adapted to panel
  **/
 static void
-retrieve_icon (GpmBrightnessApplet *applet)
+gpm_applet_get_icon (GpmBrightnessApplet *applet)
 {
 	const gchar *icon;
 
@@ -88,17 +195,21 @@ retrieve_icon (GpmBrightnessApplet *applet)
 	}
 
 	/* get icon */
-	if (applet->enabled == TRUE) {
-		icon = GPM_BRIGHTNESS_APPLET_ICON;
-	} else {
+	if (applet->proxy == NULL) {
+		icon = GPM_BRIGHTNESS_APPLET_ICON_INVALID;
+	} else if (applet->call_worked == FALSE) {
 		icon = GPM_BRIGHTNESS_APPLET_ICON_DISABLED;
+	} else {
+		icon = GPM_BRIGHTNESS_APPLET_ICON;
 	}
+
 	applet->icon = gtk_icon_theme_load_icon (gtk_icon_theme_get_default (),
 						 icon, applet->size - 2, 0, NULL);
 
 	if (applet->icon == NULL) {
-		g_warning ("Cannot find %s!", icon);
+		printf ("WARNING: Cannot find %s!\n", icon);
 	} else {
+		printf ("DEBUG: got icon %s!\n", icon);
 		/* update size cache */
 		applet->icon_height = gdk_pixbuf_get_height (applet->icon);
 		applet->icon_width = gdk_pixbuf_get_width (applet->icon);
@@ -106,52 +217,52 @@ retrieve_icon (GpmBrightnessApplet *applet)
 }
 
 /**
- * check_size:
+ * gpm_applet_check_size:
  * @applet: Brightness applet instance
  *
  * check if panel size has changed and applet adapt size
  **/
 static void
-check_size (GpmBrightnessApplet *applet)
+gpm_applet_check_size (GpmBrightnessApplet *applet)
 {
 	/* we don't use the size function here, but the yet allocated size because the
 	   size value is false (kind of rounded) */
 	if (PANEL_APPLET_VERTICAL(panel_applet_get_orient (PANEL_APPLET (applet)))) {
 		if (applet->size != GTK_WIDGET(applet)->allocation.width) {
 			applet->size = GTK_WIDGET(applet)->allocation.width;
-			retrieve_icon (applet);
+			gpm_applet_get_icon (applet);
 			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->size, applet->icon_height + 2);
 		}
 	} else {
 		if (applet->size != GTK_WIDGET(applet)->allocation.height) {
 			applet->size = GTK_WIDGET(applet)->allocation.height;
-			retrieve_icon (applet);
+			gpm_applet_get_icon (applet);
 			gtk_widget_set_size_request (GTK_WIDGET(applet), applet->icon_width + 2, applet->size);
 		}
 	}
 }
 
 /**
- * draw_applet_cb:
+ * gpm_applet_draw_cb:
  * @applet: Brightness applet instance
  *
  * draws applet content (background + icon)
  **/
 static gboolean
-draw_applet_cb (GpmBrightnessApplet *applet)
+gpm_applet_draw_cb (GpmBrightnessApplet *applet)
 {
 	gint w, h, bg_type;
-
 	GdkColor color;
-	GdkPixmap *backbuf, *background;
-	GdkGC *gc_backbuf, *gc_widget;
+	GdkGC *gc;
+	GdkPixmap *background;
 
 	if (GTK_WIDGET(applet)->window == NULL) {
 		return FALSE;
 	}
 
 	/* retrieve applet size */
-	check_size (applet);
+	gpm_applet_get_icon (applet);
+	gpm_applet_check_size (applet);
 	if (applet->size <= 2) {
 		return FALSE;
 	}
@@ -164,51 +275,62 @@ draw_applet_cb (GpmBrightnessApplet *applet)
 	w = GTK_WIDGET(applet)->allocation.width;
 	h = GTK_WIDGET(applet)->allocation.height;
 
-	/* draw background */
-	backbuf = gdk_pixmap_new (GTK_WIDGET(applet)->window, w, h, -1);
-	gc_backbuf = gdk_gc_new (backbuf);
+	gc = gdk_gc_new (GTK_WIDGET(applet)->window);
 
+	/* draw pixmap background */
 	bg_type = panel_applet_get_background (PANEL_APPLET (applet), &color, &background);
 	if (bg_type == PANEL_PIXMAP_BACKGROUND && !applet->popped) {
 		/* fill with given background pixmap */
-		gdk_draw_drawable (backbuf, gc_backbuf, background, 0, 0, 0, 0, w, h);
-	} else {
-		/* fill with appropriate color */
-		if (applet->popped) {
-			color = gtk_rc_get_style (GTK_WIDGET(applet))->bg[GTK_STATE_SELECTED];
-		} else {
-			if (bg_type == PANEL_NO_BACKGROUND) {
-				color = gtk_rc_get_style (GTK_WIDGET(applet))->bg[GTK_STATE_NORMAL];
-			}
-		}
-		gdk_gc_set_rgb_fg_color (gc_backbuf,&color);
-		gdk_gc_set_fill (gc_backbuf,GDK_SOLID);
-		gdk_draw_rectangle (backbuf, gc_backbuf, TRUE, 0, 0, w, h);
+		gdk_draw_drawable (GTK_WIDGET(applet)->window, gc, background, 0, 0, 0, 0, w, h);
+	}
+	
+	/* draw color background */
+	if (bg_type == PANEL_COLOR_BACKGROUND && !applet->popped) {
+		gdk_gc_set_rgb_fg_color (gc,&color);
+		gdk_gc_set_fill (gc,GDK_SOLID);
+		gdk_draw_rectangle (GTK_WIDGET(applet)->window, gc, TRUE, 0, 0, w, h);
+	}
+
+	/* fill with selected color if popped */
+	if (applet->popped) {
+		color = gtk_rc_get_style (GTK_WIDGET(applet))->bg[GTK_STATE_SELECTED];
+		gdk_gc_set_rgb_fg_color (gc,&color);
+		gdk_gc_set_fill (gc,GDK_SOLID);
+		gdk_draw_rectangle (GTK_WIDGET(applet)->window, gc, TRUE, 0, 0, w, h);
 	}
 
 	/* draw icon at center */
-	gdk_draw_pixbuf (backbuf, gc_backbuf, applet->icon,
+	gdk_draw_pixbuf (GTK_WIDGET(applet)->window, gc, applet->icon,
 			 0, 0, (w - applet->icon_width)/2, (h - applet->icon_height)/2,
 			 applet->icon_width, applet->icon_height,
 			 GDK_RGB_DITHER_NONE, 0, 0);
 
-	/* blit back buffer to applet */
-	gc_widget = gdk_gc_new (GTK_WIDGET(applet)->window);
-	gdk_draw_drawable (GTK_WIDGET(applet)->window,
-			   gc_widget, backbuf,
-			   0, 0, 0, 0, w, h);
+	g_object_unref (gc);
 
 	return TRUE;
 }
 
 /**
- * destroy_popup_cb:
+ * gpm_applet_change_background_cb:
+ *
+ * Enqueues an expose event (don't know why it's not the default behaviour)
+ **/
+static void
+gpm_applet_change_background_cb (GpmBrightnessApplet *applet,
+				 PanelAppletBackgroundType arg1,
+				 GdkColor *arg2, GdkPixmap *arg3, gpointer data)
+{
+	gtk_widget_queue_draw (GTK_WIDGET (applet));
+}
+
+/**
+ * gpm_applet_destroy_popup_cb:
  * @applet: Brightness applet instance
  *
  * destroys the popup (called if orientation has changed)
  **/
 static gboolean
-destroy_popup_cb (GpmBrightnessApplet *applet)
+gpm_applet_destroy_popup_cb (GpmBrightnessApplet *applet)
 {
 	if (applet->popup != NULL) {
 		gtk_widget_set_parent (applet->popup, NULL);
@@ -219,29 +341,31 @@ destroy_popup_cb (GpmBrightnessApplet *applet)
 }
 
 /**
- * update_tooltip:
+ * gpm_applet_update_tooltip:
  * @applet: Brightness applet instance
  *
  * sets tooltip's content (percentage or disabled)
  **/
 static void
-update_tooltip (GpmBrightnessApplet *applet)
+gpm_applet_update_tooltip (GpmBrightnessApplet *applet)
 {
 	static gchar buf[101];
 	if (applet->popped == FALSE) {
-		if (applet->enabled == TRUE) {
-			snprintf (buf, 100, _("LCD brightness : %d%%"), applet->level);
-		} else {
+		if (applet->proxy == NULL) {
+			snprintf (buf, 100, _("Cannot connect to gnome-power-manager"));
+		} else if (applet->call_worked == FALSE) {
 			snprintf (buf, 100, _("Cannot get laptop panel brightness"));
+		} else {
+			snprintf (buf, 100, _("LCD brightness : %d%%"), applet->level);
 		}
-		gtk_tooltips_set_tip (applet->tooltip, GTK_WIDGET(applet), buf, NULL);
+		gtk_widget_set_tooltip_text (GTK_WIDGET(applet), buf);
 	} else {
-		gtk_tooltips_set_tip (applet->tooltip, GTK_WIDGET(applet), NULL, NULL);
+		gtk_widget_set_tooltip_text (GTK_WIDGET(applet), NULL);
 	}
 }
 
 /**
- * update_level:
+ * gpm_applet_update_popup_level:
  * @applet: Brightness applet instance
  * @get_hw: set UI value from HW value
  * @set_hw: set HW value from UI value
@@ -253,73 +377,70 @@ update_tooltip (GpmBrightnessApplet *applet)
  * FALSE TRUE  -> set HW from UI value
  **/
 static void
-update_level (GpmBrightnessApplet *applet, gboolean get_hw, gboolean set_hw)
+gpm_applet_update_popup_level (GpmBrightnessApplet *applet)
 {
-	if (set_hw == TRUE) {
-		applet->enabled = gpm_powermanager_set_brightness_lcd (applet->powermanager, applet->level);
-	}
-	if (get_hw == TRUE) {
-		applet->enabled = gpm_powermanager_get_brightness_lcd (applet->powermanager, &applet->level);
-	}
 	if (applet->popup != NULL) {
-		gtk_widget_set_sensitive (applet->btn_plus,applet->level < 99);
-		gtk_widget_set_sensitive (applet->btn_minus,applet->level > 0);
+		gtk_widget_set_sensitive (applet->btn_plus, applet->level < 100);
+		gtk_widget_set_sensitive (applet->btn_minus, applet->level > 0);
 		gtk_range_set_value (GTK_RANGE(applet->slider), (guint) applet->level);
 	}
-	update_tooltip (applet);
+	gpm_applet_update_tooltip (applet);
 }
 
 /**
- * plus_cb:
+ * gpm_applet_plus_cb:
  * @widget: The sending widget (plus button)
  * @applet: Brightness applet instance
  *
  * callback for the plus button
  **/
 static gboolean
-plus_cb (GtkWidget *w, GpmBrightnessApplet *applet)
+gpm_applet_plus_cb (GtkWidget *w, GpmBrightnessApplet *applet)
 {
-	if (applet->level < 99) {
+	if (applet->level < 100) {
 		applet->level++;
 	}
-	update_level (applet, FALSE, TRUE);
+	applet->call_worked = gpm_applet_set_brightness (applet);
+	gpm_applet_update_popup_level (applet);
 	return TRUE;
 }
 
 /**
- * minus_cb:
+ * gpm_applet_minus_cb:
  * @widget: The sending widget (minus button)
  * @applet: Brightness applet instance
  *
  * callback for the minus button
  **/
 static gboolean
-minus_cb (GtkWidget *w, GpmBrightnessApplet *applet)
+gpm_applet_minus_cb (GtkWidget *w, GpmBrightnessApplet *applet)
 {
 	if (applet->level > 0) {
 		applet->level--;
 	}
-	update_level (applet, FALSE, TRUE);
+	applet->call_worked = gpm_applet_set_brightness (applet);
+	gpm_applet_update_popup_level (applet);
 	return TRUE;
 }
 
 /**
- * slide_cb:
+ * gpm_applet_slide_cb:
  * @widget: The sending widget (slider)
  * @applet: Brightness applet instance
  *
  * callback for the slider
  **/
 static gboolean
-slide_cb (GtkWidget *w, GpmBrightnessApplet *applet)
+gpm_applet_slide_cb (GtkWidget *w, GpmBrightnessApplet *applet)
 {
 	applet->level = gtk_range_get_value (GTK_RANGE(applet->slider));
-	update_level (applet, FALSE, TRUE);
+	applet->call_worked = gpm_applet_set_brightness (applet);
+	gpm_applet_update_popup_level (applet);
 	return TRUE;
 }
 
 /**
- * slide_cb:
+ * gpm_applet_slide_cb:
  * @applet: Brightness applet instance
  * @event: The key press event
  *
@@ -327,10 +448,10 @@ slide_cb (GtkWidget *w, GpmBrightnessApplet *applet)
  * mainly escape to unpop and arrows to change brightness
  **/
 static gboolean
-key_press_cb (GpmBrightnessApplet *applet, GdkEventKey *event)
+gpm_applet_key_press_cb (GpmBrightnessApplet *applet, GdkEventKey *event)
 {
 	int i;
-
+	
 	switch (event->keyval) {
 	case GDK_KP_Enter:
 	case GDK_ISO_Enter:
@@ -347,8 +468,8 @@ key_press_cb (GpmBrightnessApplet *applet, GdkEventKey *event)
 			gtk_widget_set_state (GTK_WIDGET(applet), GTK_STATE_NORMAL);
 			gtk_widget_hide (applet->popup);
 			applet->popped = FALSE;
-			draw_applet_cb (applet);
-			update_tooltip (applet);
+			gpm_applet_draw_cb (applet);
+			gpm_applet_update_tooltip (applet);
 			return TRUE;
 		} else {
 			return FALSE;
@@ -356,24 +477,24 @@ key_press_cb (GpmBrightnessApplet *applet, GdkEventKey *event)
 		break;
 	case GDK_Page_Up:
 		for (i = 0;i < 10;i++) {
-			plus_cb (NULL, applet);
+			gpm_applet_plus_cb (NULL, applet);
 		}
 		return TRUE;
 		break;
 	case GDK_Left:
 	case GDK_Up:
-		plus_cb (NULL, applet);
+		gpm_applet_plus_cb (NULL, applet);
 		return TRUE;
 		break;
 	case GDK_Page_Down:
 		for (i = 0;i < 10;i++) {
-			minus_cb (NULL, applet);
+			gpm_applet_minus_cb (NULL, applet);
 		}
 		return TRUE;
 		break;
 	case GDK_Right:
 	case GDK_Down:
-		minus_cb (NULL, applet);
+		gpm_applet_minus_cb (NULL, applet);
 		return TRUE;
 		break;
 	default:
@@ -385,41 +506,49 @@ key_press_cb (GpmBrightnessApplet *applet, GdkEventKey *event)
 }
 
 /**
- * scroll_cb:
+ * gpm_applet_scroll_cb:
  * @applet: Brightness applet instance
  * @event: The scroll event
  *
  * callback handling mouse scrolls, either when the applet
  * is not popped and the mouse is over the applet, or when
- * the applet is popped and no matter where the mouse is
+ * the applet is popped and no matter where the mouse is.
  **/
 static gboolean
-scroll_cb (GpmBrightnessApplet *applet, GdkEventScroll *event)
+gpm_applet_scroll_cb (GpmBrightnessApplet *applet, GdkEventScroll *event)
 {
+	int i;
+
 	if (event->type == GDK_SCROLL) {
 		if (event->direction == GDK_SCROLL_UP) {
-			plus_cb (NULL, applet);
+			for (i = 0;i < 5;i++) {
+				gpm_applet_plus_cb (NULL, applet);
+			}
+			
 		} else {
-			minus_cb (NULL, applet);
+			for (i = 0;i < 5;i++) {
+				gpm_applet_minus_cb (NULL, applet);
+			}
 		}
 		return TRUE;
 	}
+
 	return FALSE;
 }
 
 /**
- * create_popup:
+ * gpm_applet_create_popup:
  * @applet: Brightness applet instance
  *
  * cretes a new popup according to orientation of panel
  **/
 static void
-create_popup (GpmBrightnessApplet *applet)
+gpm_applet_create_popup (GpmBrightnessApplet *applet)
 {
 	static GtkWidget *box, *frame;
 	gint orientation = panel_applet_get_orient (PANEL_APPLET (PANEL_APPLET (applet)));
 
-	destroy_popup_cb (applet);
+	gpm_applet_destroy_popup_cb (applet);
 
 	/* slider */
 	if (PANEL_APPLET_VERTICAL(orientation)) {
@@ -432,17 +561,17 @@ create_popup (GpmBrightnessApplet *applet)
 	gtk_range_set_inverted (GTK_RANGE(applet->slider), TRUE);
 	gtk_scale_set_draw_value (GTK_SCALE(applet->slider), FALSE);
 	gtk_range_set_value (GTK_RANGE(applet->slider), applet->level);
-	g_signal_connect (G_OBJECT(applet->slider), "value-changed", G_CALLBACK(slide_cb), applet);
+	g_signal_connect (G_OBJECT(applet->slider), "value-changed", G_CALLBACK(gpm_applet_slide_cb), applet);
 
 	/* minus button */
 	applet->btn_minus = gtk_button_new_with_label ("\342\210\222"); /* U+2212 MINUS SIGN */
 	gtk_button_set_relief (GTK_BUTTON(applet->btn_minus), GTK_RELIEF_NONE);
-	g_signal_connect (G_OBJECT(applet->btn_minus), "pressed", G_CALLBACK(minus_cb), applet);
+	g_signal_connect (G_OBJECT(applet->btn_minus), "pressed", G_CALLBACK(gpm_applet_minus_cb), applet);
 
 	/* plus button */
 	applet->btn_plus = gtk_button_new_with_label ("+");
 	gtk_button_set_relief (GTK_BUTTON(applet->btn_plus), GTK_RELIEF_NONE);
-	g_signal_connect (G_OBJECT(applet->btn_plus), "pressed", G_CALLBACK(plus_cb), applet);
+	g_signal_connect (G_OBJECT(applet->btn_plus), "pressed", G_CALLBACK(gpm_applet_plus_cb), applet);
 
 	/* box */
 	if (PANEL_APPLET_VERTICAL(orientation)) {
@@ -462,18 +591,19 @@ create_popup (GpmBrightnessApplet *applet)
 	/* window */
 	applet->popup = gtk_window_new (GTK_WINDOW_POPUP);
 	GTK_WIDGET_UNSET_FLAGS (applet->popup, GTK_TOPLEVEL);
+	gtk_window_set_type_hint (GTK_WINDOW(applet->popup), GDK_WINDOW_TYPE_HINT_UTILITY);
 	gtk_widget_set_parent (applet->popup, GTK_WIDGET(applet));
 	gtk_container_add (GTK_CONTAINER(applet->popup), frame);
 }
 
 /**
- * popup_cb:
+ * gpm_applet_popup_cb:
  * @applet: Brightness applet instance
  *
  * pops and unpops
  **/
 static gboolean
-popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
+gpm_applet_popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 {
 	gint orientation, x, y;
 
@@ -490,30 +620,25 @@ popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 		gtk_widget_set_state (GTK_WIDGET(applet), GTK_STATE_NORMAL);
 		gtk_widget_hide (applet->popup);
 		applet->popped = FALSE;
-		draw_applet_cb (applet);
-		update_tooltip (applet);
+		gpm_applet_draw_cb (applet);
+		gpm_applet_update_tooltip (applet);
 		return TRUE;
 	}
 
 	/* update UI for current brightness */
-	update_level (applet, TRUE, FALSE);
-
-	/* if disabled, don't pop */
-	if (applet->enabled == FALSE) {
-		return TRUE;
-	}
+	gpm_applet_update_popup_level (applet);
 
 	/* otherwise pop */
 	applet->popped = TRUE;
-	draw_applet_cb (applet);
+	gpm_applet_draw_cb (applet);
 
 	/* create a new popup (initial or if panel parameters changed) */
 	if (applet->popup == NULL) {
-		create_popup (applet);
+		gpm_applet_create_popup (applet);
 	}
 
 	/* update UI for current brightness */
-	update_level (applet, FALSE, FALSE);
+	gpm_applet_update_popup_level (applet);
 
 	gtk_widget_show_all (applet->popup);
 
@@ -572,12 +697,36 @@ popup_cb (GpmBrightnessApplet *applet, GdkEventButton *event)
 }
 
 /**
- * dialog_about_cb:
+ * gpm_applet_theme_change_cb:
+ *
+ * Updtes icon when theme changes
+ **/
+static void
+gpm_applet_theme_change_cb (GtkIconTheme *icon_theme, gpointer data)
+{
+	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET (data);
+	gpm_applet_get_icon (applet);
+}
+
+/**
+ * gpm_applet_stop_scroll_events_cb:
+ *
+ * Prevents scroll events from reaching the tooltip
+ **/
+static void
+gpm_applet_stop_scroll_events_cb (GtkWidget *widget, GdkEvent  *event)
+{
+	if (event->type == GDK_SCROLL)
+		g_signal_stop_emission_by_name (widget, "event-after");
+}
+
+/**
+ * gpm_applet_dialog_about_cb:
  *
  * displays about dialog
  **/
 static void
-dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+gpm_applet_dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
 	GtkAboutDialog *about;
 
@@ -637,12 +786,12 @@ dialog_about_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 }
 
 /**
- * help_cb:
+ * gpm_applet_help_cb:
  *
  * open gpm help
  **/
 static void
-help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
+gpm_applet_help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 {
 	GError *error = NULL;
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(data);
@@ -665,16 +814,16 @@ help_cb (BonoboUIComponent *uic, gpointer data, const gchar *verbname)
 }
 
 /**
- * destroy_cb:
+ * gpm_applet_destroy_cb:
  * @object: Class instance to destroy
  **/
 static void
-destroy_cb (GtkObject *object)
+gpm_applet_destroy_cb (GtkObject *object)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(object);
 
-	if (applet->powermanager != NULL) {
-		g_object_unref (applet->powermanager);
+	if (applet->watch != NULL) {
+		g_object_unref (applet->watch);
 	}
 	if (applet->icon != NULL) {
 		gdk_pixbuf_unref (applet->icon);
@@ -691,6 +840,95 @@ gpm_brightness_applet_class_init (GpmBrightnessAppletClass *class)
 	/* nothing to do here */
 }
 
+static void
+brightness_changed_cb (DBusGProxy          *proxy,
+		       guint	            brightness,
+		       GpmBrightnessApplet *applet)
+{
+	printf ("DEBUG: BrightnessChanged detected: %i\n", brightness);
+	applet->level = brightness;
+}
+
+/**
+ * gpm_brightness_applet_dbus_connect:
+ **/
+gboolean
+gpm_brightness_applet_dbus_connect (GpmBrightnessApplet *applet)
+{
+	GError *error = NULL;
+
+	if (applet->connection == NULL) {
+		printf ("DEBUG: get connection\n");
+		g_clear_error (&error);
+		applet->connection = dbus_g_bus_get (DBUS_BUS_SESSION, &error);
+		if (error != NULL) {
+			printf ("WARNING: Could not connect to DBUS daemon: %s", error->message);
+			g_error_free (error);
+			applet->connection = NULL;
+			return FALSE;
+		}
+	}
+	if (applet->proxy == NULL) {
+		printf ("DEBUG: get proxy\n");
+		g_clear_error (&error);
+		applet->proxy = dbus_g_proxy_new_for_name_owner (applet->connection,
+							 GPM_DBUS_SERVICE,
+							 GPM_DBUS_PATH_BACKLIGHT,
+							 GPM_DBUS_INTERFACE_BACKLIGHT,
+							 &error);
+		if (error != NULL) {
+			printf ("WARNING: Cannot connect, maybe the daemon is not running: %s\n", error->message);
+			g_error_free (error);
+			applet->proxy = NULL;
+			return FALSE;
+		}
+		dbus_g_proxy_add_signal (applet->proxy, "BrightnessChanged",
+					 G_TYPE_UINT, G_TYPE_INVALID);
+		dbus_g_proxy_connect_signal (applet->proxy, "BrightnessChanged",
+					     G_CALLBACK (brightness_changed_cb),
+					     applet, NULL);
+		/* reset, we might be starting race */
+		applet->call_worked = gpm_applet_get_brightness (applet);
+	}
+	return TRUE;
+}
+
+/**
+ * gpm_brightness_applet_dbus_disconnect:
+ **/
+gboolean
+gpm_brightness_applet_dbus_disconnect (GpmBrightnessApplet *applet)
+{
+	if (applet->proxy != NULL) {
+		printf ("DEBUG: removing proxy\n");
+		g_object_unref (applet->proxy);
+		applet->proxy = NULL;
+	}
+	return TRUE;
+}
+
+/**
+ * watch_connection_cb:
+ * @proxy: The dbus raw proxy
+ * @status: The status of the service, where TRUE is connected
+ * @screensaver: This class instance
+ **/
+static void
+watch_connection_cb (DbusWatch           *watch,
+		     gboolean	          status,
+		     GpmBrightnessApplet *applet)
+{
+	if (status) {
+		gpm_brightness_applet_dbus_connect (applet);
+		gpm_applet_update_tooltip (applet);
+		gpm_applet_draw_cb (applet);
+	} else {
+		gpm_brightness_applet_dbus_disconnect (applet);
+		gpm_applet_update_tooltip (applet);
+		gpm_applet_draw_cb (applet);
+	}
+}
+
 /**
  * gpm_brightness_applet_init:
  * @applet: Brightness applet instance
@@ -700,14 +938,27 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 {
 	/* initialize fields */
 	applet->size = 0;
-	applet->enabled = FALSE;
+	applet->call_worked = TRUE;
 	applet->popped = FALSE;
 	applet->popup = NULL;
 	applet->icon = NULL;
-	applet->tooltip = gtk_tooltips_new ();
-	applet->powermanager = gpm_powermanager_new ();
-	update_level (applet, TRUE, FALSE);
-	update_tooltip (applet);
+	applet->connection = NULL;
+	applet->proxy = NULL;
+
+	/* Add application specific icons to search path */
+	gtk_icon_theme_append_search_path (gtk_icon_theme_get_default (),
+                                           GPM_DATA G_DIR_SEPARATOR_S "icons");
+
+
+	applet->watch = dbus_watch_new ();
+	g_signal_connect (applet->watch, "connection-changed",
+			  G_CALLBACK (watch_connection_cb), applet);
+	dbus_watch_assign (applet->watch, DBUS_WATCH_SESSION, GPM_DBUS_SERVICE);
+	gpm_brightness_applet_dbus_connect (applet);
+
+	/* coldplug */
+	applet->call_worked = gpm_applet_get_brightness (applet);
+	gpm_applet_update_popup_level (applet);
 
 	/* prepare */
 	panel_applet_set_flags (PANEL_APPLET (applet), PANEL_APPLET_EXPAND_MINOR);
@@ -716,50 +967,57 @@ gpm_brightness_applet_init (GpmBrightnessApplet *applet)
 	gtk_widget_show_all (GTK_WIDGET(applet));
 
 	/* set appropriate size and load icon accordingly */
-	check_size (applet);
-	draw_applet_cb (applet);
+	gpm_applet_draw_cb (applet);
 
 	/* connect */
 	g_signal_connect (G_OBJECT(applet), "button-press-event",
-			  G_CALLBACK(popup_cb), NULL);
+			  G_CALLBACK(gpm_applet_popup_cb), NULL);
 
 	g_signal_connect (G_OBJECT(applet), "scroll-event",
-			  G_CALLBACK(scroll_cb), NULL);
+			  G_CALLBACK(gpm_applet_scroll_cb), NULL);
 
 	g_signal_connect (G_OBJECT(applet), "key-press-event",
-			  G_CALLBACK(key_press_cb), NULL);
+			  G_CALLBACK(gpm_applet_key_press_cb), NULL);
 
-	g_signal_connect (G_OBJECT(applet), "expose-event",
-			  G_CALLBACK(draw_applet_cb), NULL);
+	/* We use g_signal_connect_after because letting the panel draw
+	 * the background is the only way to have the correct
+	 * background when a theme defines a background picture. */
+	g_signal_connect_after (G_OBJECT(applet), "expose-event",
+				G_CALLBACK(gpm_applet_draw_cb), NULL);
 
 	g_signal_connect (G_OBJECT(applet), "change-background",
-			  G_CALLBACK(draw_applet_cb), NULL);
+			  G_CALLBACK(gpm_applet_change_background_cb), NULL);
 
 	g_signal_connect (G_OBJECT(applet), "change-orient",
-			  G_CALLBACK(draw_applet_cb), NULL);
+			  G_CALLBACK(gpm_applet_draw_cb), NULL);
 
 	g_signal_connect (G_OBJECT(applet), "change-orient",
-			  G_CALLBACK(destroy_popup_cb), NULL);
+			  G_CALLBACK(gpm_applet_destroy_popup_cb), NULL);
 
 	g_signal_connect (G_OBJECT(applet), "destroy",
-			  G_CALLBACK(destroy_cb), NULL);
+			  G_CALLBACK(gpm_applet_destroy_cb), NULL);
+
+	/* prevent scroll events from reaching the tooltip */
+	g_signal_connect (G_OBJECT (applet), "event-after", G_CALLBACK (gpm_applet_stop_scroll_events_cb), NULL);
+
+	g_signal_connect (gtk_icon_theme_get_default (), "changed", G_CALLBACK (gpm_applet_theme_change_cb), applet);
 }
 
 /**
- * bonobo_cb:
+ * gpm_applet_bonobo_cb:
  * @_applet: GpmBrightnessApplet instance created by the bonobo factory
  * @iid: Bonobo id
  *
  * the function called by bonobo factory after creation
  **/
 static gboolean
-bonobo_cb (PanelApplet *_applet, const gchar *iid, gpointer data)
+gpm_applet_bonobo_cb (PanelApplet *_applet, const gchar *iid, gpointer data)
 {
 	GpmBrightnessApplet *applet = GPM_BRIGHTNESS_APPLET(_applet);
 
 	static BonoboUIVerb verbs [] = {
-		BONOBO_UI_VERB ("About", dialog_about_cb),
-		BONOBO_UI_VERB ("Help", help_cb),
+		BONOBO_UI_VERB ("About", gpm_applet_dialog_about_cb),
+		BONOBO_UI_VERB ("Help", gpm_applet_help_cb),
 		BONOBO_UI_VERB_END
 	};
 
@@ -771,7 +1029,7 @@ bonobo_cb (PanelApplet *_applet, const gchar *iid, gpointer data)
 					   DATADIR,
 					   "GNOME_BrightnessApplet.xml",
 					   NULL, verbs, applet);
-	draw_applet_cb (applet);
+	gpm_applet_draw_cb (applet);
 	return TRUE;
 }
 
@@ -786,4 +1044,4 @@ PANEL_APPLET_BONOBO_FACTORY
  /* the applet name and version */
  "BrightnessApplet", VERSION,
  /* our callback (with no user data) */
- bonobo_cb, NULL);
+ gpm_applet_bonobo_cb, NULL);
