@@ -32,6 +32,7 @@
 #include <string.h>
 #include <sys/time.h>
 #include <sys/types.h>
+#include <math.h>
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif /* HAVE_UNISTD_H */
@@ -55,6 +56,7 @@
 #include "gpm-light-sensor.h"
 #include "gpm-marshal.h"
 #include "gpm-stock-icons.h"
+#include "gpm-prefs-server.h"
 
 #define DIM_INTERVAL		10 /* ms */
 
@@ -70,9 +72,15 @@ struct GpmBacklightPrivate
 	GpmControl		*control;
 	GpmDpms			*dpms;
 	GpmIdle			*idle;
+	GpmLightSensor		*light_sensor;
 	gboolean		 can_dim;
+	gboolean		 can_sense;
 	gboolean		 can_dpms;
 	gboolean		 is_laptop;
+	gboolean		 system_is_idle;
+	GTimer			*idle_timer;
+	gfloat			 ambient_sensor_value;
+	guint			 idle_dim_timeout;
 };
 
 enum {
@@ -81,7 +89,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint	     signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmBacklight, gpm_backlight, G_TYPE_OBJECT)
 
@@ -129,11 +137,11 @@ gpm_backlight_sync_policy (GpmBacklight *backlight)
 	error = NULL;
 
 	if (on_ac == TRUE) {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_AC_SLEEP_DISPLAY, &timeout);
-		gpm_conf_get_string (backlight->priv->conf, GPM_CONF_AC_DPMS_METHOD, &dpms_method);
+		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC, &timeout);
+		gpm_conf_get_string (backlight->priv->conf, GPM_CONF_BACKLIGHT_DPMS_METHOD_AC, &dpms_method);
 	} else {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_BATT_SLEEP_DISPLAY, &timeout);
-		gpm_conf_get_string (backlight->priv->conf, GPM_CONF_BATT_DPMS_METHOD, &dpms_method);
+		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT, &timeout);
+		gpm_conf_get_string (backlight->priv->conf, GPM_CONF_BACKLIGHT_DPMS_METHOD_BATT, &dpms_method);
 	}
 
 	/* convert the string types to standard types */
@@ -291,11 +299,11 @@ gpm_backlight_get_brightness (GpmBacklight *backlight,
 /**
  * gpm_backlight_set_brightness:
  **/
-gboolean gpm_backlight_set_brightness (GpmBacklight *backlight,
-				       guint	     brightness,
-				       GError	   **error)
+gboolean
+gpm_backlight_set_brightness (GpmBacklight *backlight,
+			      guint	    brightness,
+			      GError	   **error)
 {
-	gboolean ret;
 	g_return_val_if_fail (backlight != NULL, FALSE);
 	g_return_val_if_fail (GPM_IS_BACKLIGHT (backlight), FALSE);
 
@@ -307,6 +315,10 @@ gboolean gpm_backlight_set_brightness (GpmBacklight *backlight,
 		return FALSE;
 	}
 
+	/* just set the AC brightness for now, don't try to be clever */
+	gpm_conf_set_uint (backlight->priv->conf, GPM_CONF_BACKLIGHT_BRIGHTNESS_AC, brightness);
+#if 0
+	gboolean ret;
 	/* sets the current policy brightness */
 	ret = gpm_brightness_lcd_set_std (backlight->priv->brightness, brightness);
 	if (ret == FALSE) {
@@ -314,7 +326,125 @@ gboolean gpm_backlight_set_brightness (GpmBacklight *backlight,
 				      GPM_BACKLIGHT_ERROR_GENERAL,
 				      "Cannot set policy brightness");
 	}
-	return ret;
+#endif
+
+	return TRUE;
+}
+
+/**
+ * gpm_common_sum_scale:
+ *
+ * Finds the average between value1 and value2 set on a scale factor
+ **/
+inline static gfloat
+gpm_common_sum_scale (gfloat value1, gfloat value2, gfloat factor)
+{
+	gfloat diff;
+	diff = value1 - value2;
+	return value2 + (diff * factor);
+}
+
+/**
+ * gpm_backlight_brightness_evaluate_and_set:
+ **/
+static gboolean
+gpm_backlight_brightness_evaluate_and_set (GpmBacklight *backlight, gboolean interactive)
+{
+	gfloat brightness;
+	gfloat scale;
+	gboolean on_ac;
+	gboolean do_laptop_lcd;
+	gboolean enable_action;
+	gboolean battery_reduce;
+	guint value;
+	guint old_value;
+
+	if (backlight->priv->can_dim == FALSE) {
+		gpm_warning ("no dimming hardware");
+		return FALSE;
+	}
+
+	gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_ENABLE, &do_laptop_lcd);
+	if (do_laptop_lcd == FALSE) {
+		gpm_warning ("policy is no dimming");
+		return FALSE;
+	}
+
+	/* get the 'main' brightness */
+	gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_BACKLIGHT_BRIGHTNESS_AC, &value);
+	brightness = value / 100.0f;
+	gpm_debug ("1. main brightness %f", brightness);
+
+	/* get AC status */
+	on_ac = gpm_ac_adapter_is_present (backlight->priv->ac_adapter);
+
+	/* reduce if on battery power if we should */
+	gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_BATTERY_REDUCE, &battery_reduce);
+	if (on_ac == FALSE && battery_reduce == TRUE) {
+		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_BACKLIGHT_BRIGHTNESS_BATT, &value);
+		scale = (100 - value) / 100.0f;
+		brightness *= scale;
+	} else {
+		scale = 1.0f;
+	}
+	gpm_debug ("2. battery scale %f, brightness %f", scale, brightness);
+
+	/* reduce if system is momentarily idle */
+	if (on_ac == TRUE) {
+		gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_DIM_AC, &enable_action);
+	} else {
+		gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_DIM_BATT, &enable_action);
+	}
+	if (enable_action == TRUE && backlight->priv->system_is_idle == TRUE) {
+		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_BACKLIGHT_IDLE_BRIGHTNESS, &value);
+		scale = value / 100.0f;
+		brightness *= scale;
+	} else {
+		scale = 1.0f;
+	}
+	gpm_debug ("3. idle scale %f, brightness %f", scale, brightness);
+
+	/* reduce if ambient is low */
+	gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_AMBIENT_ENABLE, &enable_action);
+	if (backlight->priv->can_sense == TRUE && enable_action == TRUE) {
+		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_AMBIENT_SCALE, &value);
+		scale = backlight->priv->ambient_sensor_value * (value / 100.0f);
+		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_AMBIENT_FACTOR, &value);
+		scale = gpm_common_sum_scale (brightness, scale, value / 100.0f);
+		if (scale > 1.0f) {
+			scale = 1.0f;
+		}
+		if (scale < 0.80f) {
+			brightness *= scale;
+		} else {
+			scale = 1.0f;
+		}
+	} else {
+		scale = 1.0f;
+	}
+	gpm_debug ("4. ambient scale %f, brightness %f", scale, brightness);
+
+	/* convert to percentage */
+	value = roundf (brightness * 100.0f);
+
+	/* only do stuff if the brightness is different */
+	gpm_brightness_lcd_get (backlight->priv->brightness, &old_value);
+	if (old_value == value) {
+		gpm_debug ("values are the same, no action");
+		return FALSE;
+	}
+
+	/* only show dialog if interactive */
+	if (interactive == TRUE) {
+		gpm_feedback_display_value (backlight->priv->feedback, (float) brightness);
+	}
+
+	/* we emit a signal for the brightness applet */
+	gpm_debug ("emitting brightness-changed : %i", value);
+	g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, value);
+
+	gpm_brightness_lcd_set_std (backlight->priv->brightness, value);
+	return TRUE;
 }
 
 /**
@@ -327,41 +457,29 @@ conf_key_changed_cb (GpmConf      *conf,
 		     const gchar  *key,
 		     GpmBacklight *backlight)
 {
-	gint value;
 	gboolean on_ac;
-
 	on_ac = gpm_ac_adapter_is_present (backlight->priv->ac_adapter);
 
-	if (strcmp (key, GPM_CONF_AC_BRIGHTNESS) == 0) {
+	if (strcmp (key, GPM_CONF_BACKLIGHT_BRIGHTNESS_AC) == 0) {
+		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 
-		if (backlight->priv->can_dim == TRUE) {
-			gpm_conf_get_int (backlight->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
-			if (on_ac == TRUE) {
-				gpm_brightness_lcd_set_std (backlight->priv->brightness, value);
-			}
-		}
-
-	} else if (strcmp (key, GPM_CONF_BATT_BRIGHTNESS) == 0) {
-
-		if (backlight->priv->can_dim == TRUE) {
-			gpm_conf_get_int (backlight->priv->conf, GPM_CONF_BATT_BRIGHTNESS, &value);
-			if (on_ac == FALSE) {
-				gpm_brightness_lcd_set_std (backlight->priv->brightness, value);
-			}
-		}
-
-	} else if (strcmp (key, GPM_CONF_PANEL_DIM_BRIGHTNESS) == 0) {
-
-		if (backlight->priv->can_dim == TRUE) {
-			gpm_conf_get_int (backlight->priv->conf, GPM_CONF_PANEL_DIM_BRIGHTNESS, &value);
-			gpm_brightness_lcd_set_dim (backlight->priv->brightness, value);
-		}
+	} else if (strcmp (key, GPM_CONF_BACKLIGHT_BRIGHTNESS_BATT) == 0) {
+		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 	}
 
-	if (strcmp (key, GPM_CONF_BATT_SLEEP_DISPLAY) == 0 ||
-	    strcmp (key, GPM_CONF_AC_SLEEP_DISPLAY) == 0 ||
-	    strcmp (key, GPM_CONF_AC_DPMS_METHOD) == 0 ||
-	    strcmp (key, GPM_CONF_BATT_DPMS_METHOD) == 0) {
+	else if (strcmp (key, GPM_CONF_BACKLIGHT_IDLE_DIM_AC) == 0 ||
+	         strcmp (key, GPM_CONF_AMBIENT_ENABLE) == 0 ||
+	         strcmp (key, GPM_CONF_AMBIENT_FACTOR) == 0 ||
+	         strcmp (key, GPM_CONF_AMBIENT_SCALE) == 0 ||
+	         strcmp (key, GPM_CONF_BACKLIGHT_ENABLE) == 0 ||
+	         strcmp (key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
+	         strcmp (key, GPM_CONF_BACKLIGHT_IDLE_BRIGHTNESS) == 0) {
+		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
+
+	} else if (strcmp (key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT) == 0 ||
+	           strcmp (key, GPM_CONF_TIMEOUT_SLEEP_DISPLAY_AC) == 0 ||
+	           strcmp (key, GPM_CONF_BACKLIGHT_DPMS_METHOD_AC) == 0 ||
+	           strcmp (key, GPM_CONF_BACKLIGHT_DPMS_METHOD_BATT) == 0) {
 		gpm_backlight_sync_policy (backlight);
 	}
 }
@@ -379,20 +497,7 @@ ac_adapter_changed_cb (GpmAcAdapter     *ac_adapter,
 		       gboolean		 on_ac,
 		       GpmBacklight     *backlight)
 {
-	gboolean do_laptop_lcd;
-	guint value;
-
-	if (on_ac == TRUE) {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
-	} else {
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_BATT_BRIGHTNESS, &value);
-	}
-
-	/* only do brightness changes if we have the hardware */
-	gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_DISPLAY_STATE_CHANGE, &do_laptop_lcd);
-	if (do_laptop_lcd == TRUE && backlight->priv->can_dim == TRUE) {
-		gpm_brightness_lcd_set_std (backlight->priv->brightness, value);
-	}
+	gpm_backlight_brightness_evaluate_and_set (backlight, TRUE);
 }
 
 /**
@@ -424,13 +529,66 @@ button_pressed_cb (GpmButton    *button,
 	} else if (strcmp (type, GPM_BUTTON_LID_OPEN) == 0) {
 
 		/* make sure we undim when we lift the lid */
-		if (backlight->priv->can_dim == TRUE) {
-			gpm_brightness_lcd_undim (backlight->priv->brightness);
-		}
+		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 		gpm_backlight_sync_policy (backlight);
 	}
 }
 
+/**
+ * gpm_backlight_notify_system_idle_changed:
+ **/
+static gboolean
+gpm_backlight_notify_system_idle_changed (GpmBacklight *backlight, gboolean is_idle)
+{
+	gdouble elapsed;
+
+	/* no point continuing */
+	if (backlight->priv->system_is_idle == is_idle) {
+		gpm_debug ("state not changed");
+		return FALSE;
+	}
+
+	/* get elapsed time and reset timer */
+	elapsed = g_timer_elapsed (backlight->priv->idle_timer, NULL);
+	g_timer_reset (backlight->priv->idle_timer);
+
+	if (is_idle == FALSE) {
+		gpm_debug ("we have just been idle for %lfs", elapsed);
+
+		/* The user immediatly undimmed the screen!
+		 * We should double the timeout to avoid this happening again */
+		if (elapsed < 10) {
+			/* double the event time */
+			backlight->priv->idle_dim_timeout *= 2.0;
+			gpm_conf_set_uint (backlight->priv->conf,
+					   GPM_CONF_GNOME_SS_PM_DELAY,
+					   backlight->priv->idle_dim_timeout);
+			gpm_debug ("increasing idle dim time to %is",
+				   backlight->priv->idle_dim_timeout);
+		}
+
+		/* We reset the dimming after 2 minutes of idle,
+		 * as the user will have changed tasks */
+		if (elapsed > 2*60) {
+			/* reset back to our default dimming */
+			gpm_conf_get_uint (backlight->priv->conf,
+					   GPM_CONF_BACKLIGHT_IDLE_DIM_TIME,
+					   &backlight->priv->idle_dim_timeout);
+			gpm_conf_set_uint (backlight->priv->conf,
+					   GPM_CONF_GNOME_SS_PM_DELAY,
+					   backlight->priv->idle_dim_timeout);
+			gpm_debug ("resetting idle dim time to %is",
+				   backlight->priv->idle_dim_timeout);
+		}
+	} else {
+		gpm_debug ("we were active for %lfs", elapsed);
+	}
+
+	gpm_debug ("changing powersave idle status to %i", is_idle);
+	backlight->priv->system_is_idle = is_idle;
+	return TRUE;
+}
+
 /**
  * idle_changed_cb:
  * @idle: The idle class instance
@@ -447,17 +605,8 @@ idle_changed_cb (GpmIdle      *idle,
 		 GpmIdleMode   mode,
 		 GpmBacklight *backlight)
 {
-	gboolean on_ac;
-	gboolean laptop_do_dim;
 	GError *error;
 
-	on_ac = gpm_ac_adapter_is_present (backlight->priv->ac_adapter);
-	if (on_ac == TRUE) {
-		gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_AC_IDLE_DIM, &laptop_do_dim);
-	} else {
-		gpm_conf_get_bool (backlight->priv->conf, GPM_CONF_BATT_IDLE_DIM, &laptop_do_dim);
-	}
-
 	/* don't dim or undim the screen when the lid is closed */
 	if (gpm_button_is_lid_closed (backlight->priv->button) == TRUE) {
 		return;
@@ -475,13 +624,13 @@ idle_changed_cb (GpmIdle      *idle,
 			}
 		}
 
+		/* sync lcd brightness */
+		gpm_backlight_notify_system_idle_changed (backlight, FALSE);
+		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
+
 		/* sync timeouts */
 		gpm_backlight_sync_policy (backlight);
 
-		if (laptop_do_dim == TRUE && backlight->priv->can_dim == TRUE) {
-			gpm_brightness_lcd_undim (backlight->priv->brightness);
-		}
-
 	} else if (mode == GPM_IDLE_MODE_SESSION) {
 
 		/* activate display power management */
@@ -494,13 +643,18 @@ idle_changed_cb (GpmIdle      *idle,
 			}
 		}
 
+		/* sync lcd brightness */
+		gpm_backlight_notify_system_idle_changed (backlight, FALSE);
+		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
+
 		/* sync timeouts */
 		gpm_backlight_sync_policy (backlight);
 
-		/* Dim the screen, fixes #328564 */
-		if (laptop_do_dim == TRUE && backlight->priv->can_dim == TRUE) {
-			gpm_brightness_lcd_dim (backlight->priv->brightness);
-		}
+	} else if (mode == GPM_IDLE_MODE_POWERSAVE) {
+
+		/* sync lcd brightness */
+		gpm_backlight_notify_system_idle_changed (backlight, TRUE);
+		gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 	}
 }
 
@@ -541,6 +695,24 @@ brightness_changed_cb (GpmBrightnessLcd *brightness,
 	g_signal_emit (backlight, signals [BRIGHTNESS_CHANGED], 0, percentage);
 }
 
+/**
+ * brightness_changed_cb:
+ * @brightness: The GpmBrightnessLcd class instance
+ * @percentage: The new percentage brightness
+ * @brightness: This class instance
+ *
+ * This callback is called when the brightness value changes.
+ **/
+static void
+sensor_changed_cb (GpmLightSensor *sensor,
+		   guint           percentage,
+		   GpmBacklight   *backlight)
+{
+	gpm_debug ("sensor changed! %i", percentage);
+	backlight->priv->ambient_sensor_value = percentage / 100.0f;
+	gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
+}
+
 /**
  * control_resume_cb:
  * @control: The control class instance
@@ -567,6 +739,11 @@ gpm_backlight_finalize (GObject *object)
 	g_return_if_fail (GPM_IS_BACKLIGHT (object));
 	backlight = GPM_BACKLIGHT (object);
 
+	g_timer_destroy (backlight->priv->idle_timer);
+
+	if (backlight->priv->light_sensor != NULL) {
+		g_object_unref (backlight->priv->light_sensor);
+	}
 	if (backlight->priv->feedback != NULL) {
 		g_object_unref (backlight->priv->feedback);
 	}
@@ -636,26 +813,56 @@ gpm_backlight_class_init (GpmBacklightClass *klass)
 static void
 gpm_backlight_init (GpmBacklight *backlight)
 {
-	gboolean on_ac;
 	HalGManager *hal_manager;
 	guint value;
+	GpmPrefsServer *prefs_server;
 
 	backlight->priv = GPM_BACKLIGHT_GET_PRIVATE (backlight);
 
+	/* record our idle time */
+	backlight->priv->idle_timer = g_timer_new ();
+
+	/* this has a delay.. */
+	backlight->priv->light_sensor = gpm_light_sensor_new ();
+	g_signal_connect (backlight->priv->light_sensor, "sensor-changed",
+			  G_CALLBACK (sensor_changed_cb), backlight);
+
 	/* gets caps */
 	backlight->priv->can_dim = gpm_brightness_lcd_has_hw ();
 	backlight->priv->can_dpms = gpm_dpms_has_hw ();
+	backlight->priv->can_sense = gpm_light_sensor_has_hw (backlight->priv->light_sensor);
 
 	/* we use hal to see if we are a laptop */
 	hal_manager = hal_gmanager_new ();
 	backlight->priv->is_laptop = hal_gmanager_is_laptop (hal_manager);
 	g_object_unref (hal_manager);
 
+	/* expose ui in prefs program */
+	prefs_server = gpm_prefs_server_new ();
+	if (backlight->priv->is_laptop == TRUE) {
+		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_LID);
+	}
+	if (backlight->priv->can_dim == TRUE) {
+		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_BACKLIGHT);
+	}
+	if (backlight->priv->can_sense == TRUE) {
+		gpm_prefs_server_set_capability (prefs_server, GPM_PREFS_SERVER_AMBIENT);
+	}
+	g_object_unref (prefs_server);
+
 	/* watch for dim value changes */
 	backlight->priv->conf = gpm_conf_new ();
 	g_signal_connect (backlight->priv->conf, "value-changed",
 			  G_CALLBACK (conf_key_changed_cb), backlight);
 
+	/* get and set the default idle dim timeout */
+	gpm_conf_get_uint (backlight->priv->conf,
+			   GPM_CONF_BACKLIGHT_IDLE_DIM_TIME,
+			   &backlight->priv->idle_dim_timeout);
+	gpm_conf_set_uint (backlight->priv->conf,
+			   GPM_CONF_GNOME_SS_PM_DELAY,
+			   backlight->priv->idle_dim_timeout);
+
 	/* watch for brightness up and down buttons and also check lid state */
 	backlight->priv->button = gpm_button_new ();
 	g_signal_connect (backlight->priv->button, "button-pressed",
@@ -666,25 +873,21 @@ gpm_backlight_init (GpmBacklight *backlight)
 	g_signal_connect (backlight->priv->ac_adapter, "ac-adapter-changed",
 			  G_CALLBACK (ac_adapter_changed_cb), backlight);
 
+	/* assumption */
+	backlight->priv->system_is_idle = FALSE;
+	gpm_conf_get_uint (backlight->priv->conf,
+			   GPM_CONF_BACKLIGHT_IDLE_DIM_TIME,
+			   &backlight->priv->idle_dim_timeout);
+	gpm_conf_set_uint (backlight->priv->conf,
+			   GPM_CONF_GNOME_SS_PM_DELAY,
+			   backlight->priv->idle_dim_timeout);
+
 	if (backlight->priv->can_dim == TRUE) {
 		/* watch for manual brightness changes (for the feedback widget) */
 		backlight->priv->brightness = gpm_brightness_lcd_new ();
 		g_signal_connect (backlight->priv->brightness, "brightness-changed",
 				  G_CALLBACK (brightness_changed_cb), backlight);
 
-		/* set the standard setting */
-		on_ac = gpm_ac_adapter_is_present (backlight->priv->ac_adapter);
-		if (on_ac == TRUE) {
-			gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_AC_BRIGHTNESS, &value);
-		} else {
-			gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_BATT_BRIGHTNESS, &value);
-		}
-		gpm_brightness_lcd_set_std (backlight->priv->brightness, value);
-
-		/* set the default dim */
-		gpm_conf_get_uint (backlight->priv->conf, GPM_CONF_PANEL_DIM_BRIGHTNESS, &value);
-		gpm_brightness_lcd_set_dim (backlight->priv->brightness, value);
-
 		/* use a visual widget */
 		backlight->priv->feedback = gpm_feedback_new ();
 		gpm_feedback_set_icon_name (backlight->priv->feedback,
@@ -709,6 +912,9 @@ gpm_backlight_init (GpmBacklight *backlight)
 			  G_CALLBACK (idle_changed_cb), backlight);
 
 	/* sync at startup */
+	gpm_light_sensor_get_absolute (backlight->priv->light_sensor, &value);
+	backlight->priv->ambient_sensor_value = value / 100.0f;
+	gpm_backlight_brightness_evaluate_and_set (backlight, FALSE);
 	gpm_backlight_sync_policy (backlight);
 }
 
