@@ -61,7 +61,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0 };
 static gpointer gpm_button_object = NULL;
 
 G_DEFINE_TYPE (GpmButton, gpm_button, G_TYPE_OBJECT)
@@ -77,26 +77,29 @@ gpm_button_filter_x_events (GdkXEvent *xevent,
 	gchar *hashkey;
 	gchar *key;
 
+	if (xev->type != KeyPress) {
+		return GDK_FILTER_CONTINUE;
+	}
+
 	keycode = xev->xkey.keycode;
 	state = xev->xkey.state;
 
-	if (xev->type != KeyPress) {
-		hashkey = g_strdup_printf ("key_%x_%x", state, keycode);
-
-		/* is the key string already in our DB? */
-		key = g_hash_table_lookup (button->priv->hash_to_hal, hashkey);
-		if (key == NULL) {
-			gpm_warning ("Key '%s' not found in hash!", hashkey);
-		} else {
-			gpm_debug ("Key '%s' mapped to HAL key %s", hashkey, key);
-			g_signal_emit (button, signals [BUTTON_PRESSED], 0, key);
-		}
+	hashkey = g_strdup_printf ("key_%x_%x", state, keycode);
 
+	/* is the key string already in our DB? */
+	key = g_hash_table_lookup (button->priv->hash_to_hal, hashkey);
+	if (key == NULL) {
+		gpm_debug ("Key '%s' not found in hash", hashkey);
+		/* pass normal keypresses on, which might help with accessibility access */
 		g_free (hashkey);
-		return GDK_FILTER_REMOVE;
+		return GDK_FILTER_CONTINUE;
 	}
 
-	return GDK_FILTER_CONTINUE;
+	gpm_debug ("Key '%s' mapped to HAL key %s", hashkey, key);
+	g_signal_emit (button, signals [BUTTON_PRESSED], 0, key);
+
+	g_free (hashkey);
+	return GDK_FILTER_REMOVE;
 }
 
 /**
@@ -312,7 +315,6 @@ emit_button_pressed (GpmButton   *button,
 			return;
 		}
 		button->priv->lid_is_closed = TRUE;
-		gpm_sound_event (button->priv->sound, GPM_SOUND_LID_DOWN);
 	}
 	if (strcmp (atype, GPM_BUTTON_LID_OPEN) == 0) {
 		if (button->priv->lid_is_closed == FALSE) {
@@ -320,7 +322,6 @@ emit_button_pressed (GpmButton   *button,
 			return;
 		}
 		button->priv->lid_is_closed = FALSE;
-		gpm_sound_event (button->priv->sound, GPM_SOUND_LID_UP);
 	}
 
 	/* the names changed in 0.5.8 */
