@@ -84,7 +84,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmCellArray, gpm_cell_array, G_TYPE_OBJECT)
 
@@ -154,12 +154,12 @@ gpm_cell_array_get_cell (GpmCellArray *cell_array, guint id)
 {
 	GpmCell *cell;
 
-	g_return_val_if_fail (cell_array != NULL, 0);
-	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), 0);
+	g_return_val_if_fail (cell_array != NULL, NULL);
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), NULL);
 
 	if (id > cell_array->priv->array->len) {
 		gpm_warning ("not valid cell id");
-		return FALSE;
+		return NULL;
 	}
 
 	cell = (GpmCell *) g_ptr_array_index (cell_array->priv->array, id);
@@ -730,6 +730,14 @@ gpm_cell_array_collection_changed (GpmCellArray *cell_array)
 {
 	GpmCellUnit *unit;
 	gchar *config_id;
+	guint length;
+
+	length = cell_array->priv->array->len;
+	/* if we have no devices, don't try to get refresh anything */
+	if (length == 0) {
+		gpm_debug ("no devices of type");
+		return FALSE;
+	}
 
 	unit = &(cell_array->priv->unit);
 
@@ -925,8 +933,8 @@ gpm_cell_array_get_description (GpmCellArray *cell_array)
 	GpmCellUnit *unit;
 	gboolean plural = FALSE;
 
-	g_return_val_if_fail (cell_array != NULL, 0);
-	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), 0);
+	g_return_val_if_fail (cell_array != NULL, NULL);
+	g_return_val_if_fail (GPM_IS_CELL_ARRAY (cell_array), NULL);
 
 	unit = &(cell_array->priv->unit);
 
@@ -1424,6 +1432,7 @@ gpm_cell_array_finalize (GObject *object)
 	g_object_unref (cell_array->priv->profile);
 	g_object_unref (cell_array->priv->conf);
 	g_object_unref (cell_array->priv->control);
+	G_OBJECT_CLASS (gpm_cell_array_parent_class)->finalize (object);
 }
 
 /**
@@ -1488,17 +1497,21 @@ gpm_st_cell_array (GpmSelfTest *test)
 
 	/************************************************************/
 	gpm_st_title (test, "make sure we got a single recall notice");
+	if (recall_count2 == 0) {
+		gpm_st_warning (test, "did not get recall - install fdi!");
+		goto out;
+	}
 	if (recall_count2 == 1) {
 		gpm_st_success (test, "got recall");
 	} else {
-		gpm_st_failed (test, "did not get recall (install fdi?)");
+		gpm_st_failed (test, "got duplicate recall");
 	}
 
 	/************************************************************/
 	gpm_st_title (test, "make sure we got at least 1 cell");
 	count = gpm_cell_array_get_num_cells (cell_array);
 	if (count >= 1) {
-	gpm_st_success (test, "got %d cell(s)", count);
+		gpm_st_success (test, "got %d cell(s)", count);
 	} else {
 		gpm_st_failed (test, "got %i cells", count);
 	}
@@ -1522,6 +1535,7 @@ gpm_st_cell_array (GpmSelfTest *test)
 		gpm_st_failed (test, "could not get correct cell");
 	}
 
+out:
 	g_object_unref (cell_array);
 
 	gpm_st_end (test);
