@@ -29,14 +29,16 @@ typedef enum {
 	GPM_CELL_UNIT_KIND_UPS,
 	GPM_CELL_UNIT_KIND_MOUSE,
 	GPM_CELL_UNIT_KIND_KEYBOARD,
+	GPM_CELL_UNIT_KIND_PHONE,
 	GPM_CELL_UNIT_KIND_PDA,
+	GPM_CELL_UNIT_KIND_UNKNOWN
 } GpmCellUnitKind;
 
 typedef enum {
 	GPM_CELL_UNIT_MWH,
 	GPM_CELL_UNIT_CSR,
 	GPM_CELL_UNIT_PERCENT,
-	GPM_CELL_UNIT_UNKNOWN,
+	GPM_CELL_UNIT_UNKNOWN
 } GpmCellUnitMeasure;
 
 typedef struct {
