@@ -1,7 +1,7 @@
 /* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*-
  *
  * Copyright (C) 2005 William Jon McCann <mccann@jhu.edu>
- * Copyright (C) 2005-2006 Richard Hughes <richard@hughsie.com>
+ * Copyright (C) 2005-2007 Richard Hughes <richard@hughsie.com>
  *
  * Licensed under the GNU General Public License Version 2
  *
@@ -31,16 +31,23 @@ G_BEGIN_DECLS
 #if defined(__STDC_VERSION__) && __STDC_VERSION__ >= 199901L
 #define gpm_debug(...) gpm_debug_real (__func__, __FILE__, __LINE__, __VA_ARGS__)
 #define gpm_warning(...) gpm_warning_real (__func__, __FILE__, __LINE__, __VA_ARGS__)
+#define gpm_error(...) gpm_error_real (__func__, __FILE__, __LINE__, __VA_ARGS__)
+#define gpm_assert_run_once(x) static guint (x) = 0; if ((x)++ != 0) gpm_error ("%s, run multi!", __func__); gpm_warning ("%s, run multi!", __func__);
 #elif defined(__GNUC__) && __GNUC__ >= 3
 #define gpm_debug(...) gpm_debug_real (__FUNCTION__, __FILE__, __LINE__, __VA_ARGS__)
 #define gpm_warning(...) gpm_warning_real (__FUNCTION__, __FILE__, __LINE__, __VA_ARGS__)
+#define gpm_error(...) gpm_error_real (__FUNCTION__, __FILE__, __LINE__, __VA_ARGS__)
+#define gpm_assert_run_once(x) static guint (x) = 0; if ((x)++ != 0) gpm_error ("%s, run multi!", __FUNCTION__); gpm_warning ("%s, run multi!", __FUNCTION__);
 #else
 #define gpm_debug
 #define gpm_warning
+#define gpm_error
+#define gpm_assert_run_once(x)
 #endif
 
 void		gpm_debug_init			(gboolean	 debug);
 void		gpm_debug_shutdown		(void);
+gboolean	gpm_debug_is_verbose		(void);
 void		gpm_debug_real			(const gchar	*func,
 						 const gchar	*file,
 						 int		 line,
@@ -49,10 +56,12 @@ void		gpm_warning_real		(const gchar	*func,
 						 const gchar	*file,
 						 int		 line,
 						 const gchar	*format, ...);
+void		gpm_error_real			(const gchar	*func,
+						 const gchar	*file,
+						 int		 line,
+						 const gchar	*format, ...);
 void		gpm_syslog			(const gchar	*format, ...);
-void		gpm_critical_error		(const gchar	*format, ...);
-void		gpm_bugzilla			(void);
-void		gpm_add_debug_option		(const gchar	*option);
+void		gpm_debug_add_option		(const gchar	*option);
 
 G_END_DECLS
 
