@@ -52,6 +52,9 @@ static void     gpm_info_finalize   (GObject      *object);
 #define GPM_INFO_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GPM_TYPE_INFO, GpmInfoPrivate))
 
 #define GPM_INFO_DATA_POLL		5	/* seconds */
+#define GPM_COLOUR_CHARGING			GPM_COLOUR_BLUE
+#define GPM_COLOUR_DISCHARGING			GPM_COLOUR_DARK_RED
+#define GPM_COLOUR_CHARGED			GPM_COLOUR_GREEN
 
 #define GPM_DBUS_STRUCT_INT_INT (dbus_g_type_get_struct ("GValueArray", \
 	G_TYPE_INT, G_TYPE_INT, G_TYPE_INVALID))
@@ -115,7 +118,10 @@ gpm_info_explain_reason (GpmInfo      *info,
 {
 	gchar *message;
 	if (post) {
-		message = g_strdup_printf (_("%s because %s"), pre, post);
+		gchar *reason;
+		reason = g_strdup_printf (_("Reason: %s"), post);
+		message = g_strconcat (pre, " ", reason, NULL);
+		g_free (reason);
 	} else {
 		message = g_strdup (pre);
 	}
@@ -198,6 +204,10 @@ gpm_statistics_add_events_typical (GPtrArray *array)
 				       GPM_COLOUR_DARK_BLUE,
 				       GPM_GRAPH_WIDGET_SHAPE_CIRCLE,
 				       _("On battery"));
+	gpm_statistics_add_event_type (array, GPM_EVENT_SESSION_POWERSAVE,
+				       GPM_COLOUR_WHITE,
+				       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
+				       _("Session powersave"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_SESSION_IDLE,
 				       GPM_COLOUR_YELLOW,
 				       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
@@ -209,15 +219,18 @@ gpm_statistics_add_events_typical (GPtrArray *array)
 	gpm_statistics_add_event_type (array, GPM_EVENT_SUSPEND,
 				       GPM_COLOUR_RED,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
-				       _("Suspend"));
+				/* Translators: translate ONLY the string part after the |*/
+				       Q_("label shown on graph|Suspend"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_RESUME,
 				       GPM_COLOUR_DARK_RED,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
-				       _("Resume"));
+				/* Translators: translate ONLY the string part after the |*/
+				       Q_("label shown on graph|Resume"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_HIBERNATE,
 				       GPM_COLOUR_MAGENTA,
 				       GPM_GRAPH_WIDGET_SHAPE_DIAMOND,
-				       _("Hibernate"));
+				/* Translators: translate ONLY the string part after the |*/
+				       Q_("label shown on graph|Hibernate"));
 	gpm_statistics_add_event_type (array, GPM_EVENT_LID_CLOSED,
 				       GPM_COLOUR_GREEN,
 				       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
@@ -281,8 +294,8 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_x = g_strdup ("time");
 		*axis_type_y = g_strdup ("power");
 		*axis_desc_x = g_strdup (_("Time since startup"));
-		*axis_desc_y = g_strdup (_("Power (mWh)"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Power"));
+		*axis_desc_y = g_strdup (_("Power"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Power"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -291,7 +304,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Time since startup"));
 		*axis_desc_y = g_strdup (_("Estimated time"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Time"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Time"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -300,7 +313,7 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Time since startup"));
 		*axis_desc_y = g_strdup (_("Battery percentage"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Percentage"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("Percentage"));
 		gpm_statistics_add_events_typical (*key_event);
 		return TRUE;
 	}
@@ -318,16 +331,16 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Accuracy of reading"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_BLUE, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Charge Void"));
+				 	      _("Start point"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
 					       GPM_COLOUR_YELLOW,
 					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Discharge Void"));
+				 	      _("Stop point"));
 		return TRUE;
 	}
 	if (strcmp (type, "profile-charge-time") == 0) {
@@ -335,16 +348,17 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Average time elapsed"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Valid data"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_BLUE, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Extrapolated data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Charge Void"));
+				 	      _("Start point"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
 					       GPM_COLOUR_YELLOW,
 					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Discharge Void"));
+				 	      _("Stop point"));
 		return TRUE;
 	}
 	if (strcmp (type, "profile-discharge-accuracy") == 0) {
@@ -352,16 +366,16 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("percentage");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Accuracy of reading"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
 		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Charge Void"));
+				 	      _("Start point"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
 					       GPM_COLOUR_YELLOW,
 					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Discharge Void"));
+				 	      _("Stop point"));
 		return TRUE;
 	}
 	if (strcmp (type, "profile-discharge-time") == 0) {
@@ -369,16 +383,17 @@ gpm_statistics_get_parameters (GpmInfo   *info,
 		*axis_type_y = g_strdup ("time");
 		*axis_desc_x = g_strdup (_("Battery percentage"));
 		*axis_desc_y = g_strdup (_("Average time elapsed"));
-		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_RED, _("Valid data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_GREEN, _("Valid data"));
 		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_DARK_RED, _("No data"));
+		gpm_statistics_add_data_type (*key_data, GPM_COLOUR_BLUE, _("Extrapolated data"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_HIBERNATE,
 					       GPM_COLOUR_CYAN,
 					       GPM_GRAPH_WIDGET_SHAPE_SQUARE,
-				 	      _("Charge Void"));
+				 	      _("Start point"));
 		gpm_statistics_add_event_type (*key_event, GPM_EVENT_SUSPEND,
 					       GPM_COLOUR_YELLOW,
 					       GPM_GRAPH_WIDGET_SHAPE_TRIANGLE,
-				 	      _("Discharge Void"));
+				 	      _("Stop point"));
 		return TRUE;
 	}
 
@@ -425,22 +440,22 @@ gpm_statistics_get_data_types (GpmInfo  *info,
 	if (array != NULL && gpm_array_get_size (array) > 2) {
 		list = g_list_append (list, "voltage");
 	}
-	array = gpm_profile_get_data_accuracy_percent (info->priv->profile, FALSE);
-	if (array != NULL && gpm_array_get_size (array) > 2) {
-		list = g_list_append (list, "profile-charge-accuracy");
-	}
 	array = gpm_profile_get_data_time_percent (info->priv->profile, FALSE);
 	if (array != NULL && gpm_array_get_size (array) > 2) {
 		list = g_list_append (list, "profile-charge-time");
 	}
-	array = gpm_profile_get_data_accuracy_percent (info->priv->profile, TRUE);
-	if (array != NULL && gpm_array_get_size (array) > 2) {
-		list = g_list_append (list, "profile-discharge-accuracy");
-	}
 	array = gpm_profile_get_data_time_percent (info->priv->profile, TRUE);
 	if (array != NULL && gpm_array_get_size (array) > 2) {
 		list = g_list_append (list, "profile-discharge-time");
 	}
+	array = gpm_profile_get_data_accuracy_percent (info->priv->profile, FALSE);
+	if (array != NULL && gpm_array_get_size (array) > 2) {
+		list = g_list_append (list, "profile-charge-accuracy");
+	}
+	array = gpm_profile_get_data_accuracy_percent (info->priv->profile, TRUE);
+	if (array != NULL && gpm_array_get_size (array) > 2) {
+		list = g_list_append (list, "profile-discharge-accuracy");
+	}
 
 	*types = device_list_to_strv (list);
 
@@ -714,9 +729,10 @@ idle_changed_cb (GpmIdle     *idle,
 {
 	if (mode == GPM_IDLE_MODE_NORMAL) {
 		gpm_info_event_log (info, GPM_EVENT_SESSION_ACTIVE, _("idle mode ended"));
-
 	} else if (mode == GPM_IDLE_MODE_SESSION) {
 		gpm_info_event_log (info, GPM_EVENT_SESSION_IDLE, _("idle mode started"));
+	} else if (mode == GPM_IDLE_MODE_POWERSAVE) {
+		gpm_info_event_log (info, GPM_EVENT_SESSION_POWERSAVE, _("powersave mode started"));
 	}
 }
 
@@ -861,7 +877,7 @@ gpm_info_init (GpmInfo *info)
 		/* get the maximum x-axis size from gconf */
 		GpmConf *conf = gpm_conf_new ();
 		guint max_time;
-		gpm_conf_get_uint (conf, GPM_CONF_GRAPH_DATA_MAX_TIME, &max_time);
+		gpm_conf_get_uint (conf, GPM_CONF_STATS_MAX_TIME, &max_time);
 		g_object_unref (conf);
 
 		gpm_array_set_max_width (info->priv->events, max_time);
