@@ -74,7 +74,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint	     signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmPrefs, gpm_prefs, G_TYPE_OBJECT)
 
@@ -672,8 +672,16 @@ conf_key_changed_cb (GpmConf     *conf,
 		     const gchar *key,
 		     GpmPrefs    *prefs)
 {
+	int value;
+	GtkWidget *widget;
 	gboolean  enabled;
 
+	if (strcmp (key, GPM_CONF_BACKLIGHT_BRIGHTNESS_AC) == 0) {
+		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hscale_ac_brightness");
+		gpm_conf_get_int (conf, key, &value);
+		gtk_range_set_value (GTK_RANGE (widget), value);
+	}
+
 	if (strcmp (key, GPM_CONF_LOWPOWER_AC) == 0) {
 		gpm_conf_get_bool (prefs->priv->conf, GPM_CONF_LOWPOWER_AC, &enabled);
 		gpm_debug ("need to enable checkbox");
@@ -916,6 +924,7 @@ prefs_setup_ac (GpmPrefs *prefs)
 				 ACTION_BLANK,
 				 ACTION_SUSPEND,
 				 ACTION_HIBERNATE,
+				 ACTION_SHUTDOWN,
 				 NULL};
 
 	gpm_prefs_setup_action_combo (prefs, "combobox_ac_lid",
@@ -973,6 +982,7 @@ prefs_setup_battery (GpmPrefs *prefs)
 				 ACTION_BLANK,
 				 ACTION_SUSPEND,
 				 ACTION_HIBERNATE,
+				 ACTION_SHUTDOWN,
 				 NULL};
 	const gchar  *battery_critical_actions[] =
 				{ACTION_NOTHING,
@@ -1001,8 +1011,10 @@ prefs_setup_battery (GpmPrefs *prefs)
 				      GPM_CONF_TIMEOUT_SLEEP_COMPUTER_BATT);
 	gpm_prefs_setup_sleep_slider (prefs, "hscale_battery_display",
 				      GPM_CONF_TIMEOUT_SLEEP_DISPLAY_BATT);
-	gpm_prefs_setup_brightness_slider (prefs, "hscale_battery_brightness",
-					   GPM_CONF_BACKLIGHT_BRIGHTNESS_BATT);
+
+	/* set up the battery reduce checkbox */
+	gpm_prefs_setup_checkbox (prefs, "checkbutton_battery_display_reduce",
+	  			  GPM_CONF_BACKLIGHT_BATTERY_REDUCE);
 
 	gpm_prefs_setup_checkbox (prefs, "checkbutton_battery_display_dim",
 				  GPM_CONF_BACKLIGHT_IDLE_DIM_BATT);
@@ -1025,8 +1037,6 @@ prefs_setup_battery (GpmPrefs *prefs)
 		gtk_widget_hide_all (widget);
 	}
 	if (prefs->priv->has_lcd == FALSE) {
-		widget = glade_xml_get_widget (prefs->priv->glade_xml, "hbox_battery_brightness");
-		gtk_widget_hide_all (widget);
 		widget = glade_xml_get_widget (prefs->priv->glade_xml, "checkbutton_battery_display_dim");
 		gtk_widget_hide_all (widget);
 	}
