@@ -47,12 +47,13 @@ struct GpmScreensaverPrivate
 enum {
 	GS_DELAY_CHANGED,
 	CONNECTION_CHANGED,
-	IDLE_CHANGED,
+	SESSION_IDLE_CHANGED,
+	POWERSAVE_IDLE_CHANGED,
 	AUTH_REQUEST,
 	LAST_SIGNAL
 };
 
-static guint signals [LAST_SIGNAL] = { 0, };
+static guint signals [LAST_SIGNAL] = { 0 };
 static gpointer gpm_screensaver_object = NULL;
 
 G_DEFINE_TYPE (GpmScreensaver, gpm_screensaver, G_TYPE_OBJECT)
@@ -83,12 +84,23 @@ gpm_screensaver_auth_end (DBusGProxy     *proxy,
  *  has entered a valid password or re-authenticated.
  */
 static void
-gpm_screensaver_idle_changed (DBusGProxy     *proxy,
+gpm_screensaver_session_idle_changed (DBusGProxy     *proxy,
 			      gboolean        is_idle,
 			      GpmScreensaver *screensaver)
 {
-	gpm_debug ("emitting idle-changed : (%i)", is_idle);
-	g_signal_emit (screensaver, signals [IDLE_CHANGED], 0, is_idle);
+	gpm_debug ("emitting session-idle-changed : (%i)", is_idle);
+	g_signal_emit (screensaver, signals [SESSION_IDLE_CHANGED], 0, is_idle);
+}
+
+/** Invoked after a short delay
+ */
+static void
+gpm_screensaver_powersave_idle_changed (DBusGProxy     *proxy,
+			                gboolean        is_idle,
+			                GpmScreensaver *screensaver)
+{
+	gpm_debug ("emitting powersave-idle-changed : (%i)", is_idle);
+	g_signal_emit (screensaver, signals [POWERSAVE_IDLE_CHANGED], 0, is_idle);
 }
 
 /**
@@ -128,7 +140,14 @@ gpm_screensaver_proxy_connect_more (GpmScreensaver *screensaver)
 	dbus_g_proxy_add_signal (proxy, "SessionIdleChanged", G_TYPE_BOOLEAN, G_TYPE_INVALID);
 	dbus_g_proxy_connect_signal (proxy,
 				     "SessionIdleChanged",
-				     G_CALLBACK (gpm_screensaver_idle_changed),
+				     G_CALLBACK (gpm_screensaver_session_idle_changed),
+				     screensaver, NULL);
+
+	/* get SessionIdleChanged */
+	dbus_g_proxy_add_signal (proxy, "SessionPowerManagementIdleChanged", G_TYPE_BOOLEAN, G_TYPE_INVALID);
+	dbus_g_proxy_connect_signal (proxy,
+				     "SessionPowerManagementIdleChanged",
+				     G_CALLBACK (gpm_screensaver_powersave_idle_changed),
 				     screensaver, NULL);
 
 	return TRUE;
@@ -159,6 +178,7 @@ gconf_key_changed_cb (GpmConf        *conf,
 		      GpmScreensaver *screensaver)
 {
 	g_return_if_fail (GPM_IS_SCREENSAVER (screensaver));
+	gpm_debug ("key : %s", key);
 
 	if (strcmp (key, GS_PREF_IDLE_DELAY) == 0) {
 		gpm_conf_get_uint (screensaver->priv->conf, key, &screensaver->priv->idle_delay);
@@ -264,19 +284,19 @@ gpm_screensaver_add_throttle (GpmScreensaver *screensaver,
 	guint32  cookie;
 	DBusGProxy *proxy;
 
-	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), FALSE);
+	g_return_val_if_fail (GPM_IS_SCREENSAVER (screensaver), 0);
 	g_return_val_if_fail (reason != NULL, 0);
 
 	proxy = dbus_proxy_get_proxy (screensaver->priv->gproxy);
 	if (proxy == NULL) {
 		gpm_warning ("not connected");
-		return FALSE;
+		return 0;
 	}
 
 	/* shouldn't be, but make sure proxy valid */
 	if (proxy == NULL) {
 		gpm_warning ("g-s proxy is NULL!");
-		return FALSE;
+		return 0;
 	}
 
 	ret = dbus_g_proxy_call (proxy, "Throttle", &error,
@@ -474,11 +494,20 @@ gpm_screensaver_class_init (GpmScreensaverClass *klass)
 			      g_cclosure_marshal_VOID__BOOLEAN,
 			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
 
-	signals [IDLE_CHANGED] =
-		g_signal_new ("idle-changed",
+	signals [SESSION_IDLE_CHANGED] =
+		g_signal_new ("session-idle-changed",
 			      G_TYPE_FROM_CLASS (object_class),
 			      G_SIGNAL_RUN_LAST,
-			      G_STRUCT_OFFSET (GpmScreensaverClass, idle_changed),
+			      G_STRUCT_OFFSET (GpmScreensaverClass, session_idle_changed),
+			      NULL,
+			      NULL,
+			      g_cclosure_marshal_VOID__BOOLEAN,
+			      G_TYPE_NONE, 1, G_TYPE_BOOLEAN);
+	signals [POWERSAVE_IDLE_CHANGED] =
+		g_signal_new ("powersave-idle-changed",
+			      G_TYPE_FROM_CLASS (object_class),
+			      G_SIGNAL_RUN_LAST,
+			      G_STRUCT_OFFSET (GpmScreensaverClass, session_idle_changed),
 			      NULL,
 			      NULL,
 			      g_cclosure_marshal_VOID__BOOLEAN,
