@@ -57,14 +57,14 @@ static void	gpm_statistics_refresh_data (GpmStatistics *statistics);
 #define ACTION_PROFILE_CHARGE_ACCURACY		"profile-charge-accuracy"
 #define ACTION_PROFILE_DISCHARGE_TIME		"profile-discharge-time"
 #define ACTION_PROFILE_DISCHARGE_ACCURACY	"profile-discharge-accuracy"
-#define ACTION_CHARGE_TEXT			_("Charge History")
-#define ACTION_POWER_TEXT			_("Power History")
-#define ACTION_VOLTAGE_TEXT			_("Voltage History")
-#define ACTION_TIME_TEXT			_("Estimated Time History")
-#define ACTION_PROFILE_CHARGE_TIME_TEXT		_("Profiled Charge Time")
-#define ACTION_PROFILE_CHARGE_ACCURACY_TEXT	_("Profiled Charge Accuracy")
-#define ACTION_PROFILE_DISCHARGE_TIME_TEXT	_("Profiled Discharge Time")
-#define ACTION_PROFILE_DISCHARGE_ACCURACY_TEXT	_("Profiled Discharge Accuracy")
+#define ACTION_CHARGE_TEXT			_("Charge history")
+#define ACTION_POWER_TEXT			_("Power history")
+#define ACTION_VOLTAGE_TEXT			_("Voltage history")
+#define ACTION_TIME_TEXT			_("Estimated time history")
+#define ACTION_PROFILE_CHARGE_TIME_TEXT		_("Charge time profile")
+#define ACTION_PROFILE_DISCHARGE_TIME_TEXT	_("Discharge time profile")
+#define ACTION_PROFILE_CHARGE_ACCURACY_TEXT	_("Charge time accuracy profile")
+#define ACTION_PROFILE_DISCHARGE_ACCURACY_TEXT	_("Discharge time accuracy profile")
 
 #define GPM_STATISTICS_POLL_INTERVAL	15000 /* ms */
 
@@ -87,7 +87,7 @@ enum {
 	LAST_SIGNAL
 };
 
-static guint	     signals [LAST_SIGNAL] = { 0, };
+static guint	     signals [LAST_SIGNAL] = { 0 };
 
 G_DEFINE_TYPE (GpmStatistics, gpm_statistics, G_TYPE_OBJECT)
 
@@ -281,7 +281,7 @@ static void
 gpm_statistics_refresh_events (GpmStatistics *statistics)
 {
 	gpm_statistics_get_events (statistics);
-	gpm_graph_widget_set_events (GPM_GRAPH_WIDGET (statistics->priv->graph_widget),
+	gpm_graph_widget_events_add (GPM_GRAPH_WIDGET (statistics->priv->graph_widget),
 				     statistics->priv->events);
 }
 
@@ -626,7 +626,7 @@ gpm_statistics_refresh_data (GpmStatistics *statistics)
 
 		arrayfloat = gpm_array_float_new (gpm_array_get_size (statistics->priv->data));
 		gpm_array_float_from_array_y (arrayfloat, statistics->priv->data);
-		kernel = gpm_array_float_compute_gaussian (17, 4.0);
+		kernel = gpm_array_float_compute_gaussian (35, 4.5);
 		result = gpm_array_float_convolve (arrayfloat, kernel);
 		gpm_array_float_to_array_y (result, statistics->priv->data);
 
@@ -635,8 +635,9 @@ gpm_statistics_refresh_data (GpmStatistics *statistics)
 		gpm_array_float_free (result);
 	}
 
-	gpm_graph_widget_set_data (GPM_GRAPH_WIDGET (statistics->priv->graph_widget),
-				   statistics->priv->data, 0);
+	gpm_graph_widget_data_clear (GPM_GRAPH_WIDGET (statistics->priv->graph_widget));
+	gpm_graph_widget_data_add (GPM_GRAPH_WIDGET (statistics->priv->graph_widget),
+				   statistics->priv->data);
 
 	gtk_widget_hide (GTK_WIDGET (statistics->priv->graph_widget));
 	gtk_widget_show (GTK_WIDGET (statistics->priv->graph_widget));
